import java.awt.Color;
import java.util.*;
import edu.umd.cs.piccolo.PLayer;
import edu.umd.cs.piccolo.PNode;
import edu.umd.cs.piccolo.nodes.PPath;
import edu.umd.cs.piccolo.nodes.PText;





public class Diagram {
	
	private FileStructure fileStructure;
	private ArrayList<Segment> segments = new ArrayList<Segment>();
	private int radius;
	private PNode diagramNode;
	private int mode;

//	private int startDegree;
//	private int maxDegree;
//	
	public Diagram(FileStructure filestructure, int radius, PLayer layer, int mode) {
		this.fileStructure = filestructure;
		this.radius = radius;
		this.mode = mode;
		this.diagramNode = new PNode();
//		this.startDegree = startDegree;
//		this.maxDegree = maxDegree;
		calculateRings(null, this.fileStructure, layer);
	}
	
	public Diagram(FileStructure filestructure, int radius, PLayer layer, Segment root, int mode) {
		this.fileStructure = filestructure;
		this.radius = radius;
		this.mode = mode;
		this.diagramNode = new PNode();
		calculateRings(root, this.fileStructure, layer);
	}
	
	private void calculateRings(Segment parent, FileStructure tmpFileStructure, PLayer layer) {	
		if (parent != null) {
			ArrayList<FileObject> files = tmpFileStructure.getFileObjects();
			ArrayList<FileStructure> folders = tmpFileStructure.getFileStructure();
			double startDegree = parent.getStartDegree();
			double maxDegree = parent.getEndDegree();
			System.out.println("PARENTSTARTDEGREE: " + startDegree + " " + "PARENTMAXDEGREE " + maxDegree);
			System.out.println("------------------------------------");
			for (int i = 0; i < files.size(); i++) {
				double percentage = files.get(i).getFilePercentage();
				double endDegree = 360.0 / 100.0 * percentage + startDegree;
//				if (startDegree + endDegree > maxDegree) {
//					endDegree = maxDegree;
//				}
//				if (startDegree + endDegree < maxDegree && i == files.size()-1 && folders == null) {
//					endDegree = maxDegree;
//				}
				System.out.println("FILENAME: " + files.get(i).getFileName());
//				System.out.println("FILESIZE: " + files.get(i).getFileSize());
//				System.out.println("FILEPERCENTAGE: " + files.get(i).getFilePercentage());
				System.out.println("STARTDEGREE: " + startDegree + " ENDDEGREE: " + endDegree);
				Segment tmpSegment = new Segment(this.radius, startDegree, endDegree, parent, files.get(i).getFileName(), Color.green, this.segments, this.mode);
				segments.add(tmpSegment);
				startDegree = endDegree;
			}		
			for (int i = 0; i < folders.size(); i++) {
				double percentage = folders.get(i).getDirectoryPercentage();
				double endDegree = 360.0 / 100.0 * percentage + startDegree;
//				if (startDegree + endDegree > maxDegree) {
//					endDegree = maxDegree;
//				} 
//				if (startDegree + endDegree < 360 && i == folders.size() - 1) {
//					endDegree = maxDegree;
//				}
				System.out.println("DIRECTORYNAME: " + folders.get(i).getDirectoryName());
//				System.out.println("DIRECTORYSIZE: " + folders.get(i).getDirectorySize());
				System.out.println("DIRECTORYPERCENTAGE: " + folders.get(i).getDirectoryPercentage());
				System.out.println("STARTDEGREE: " + startDegree + " ENDDEGREE: " + endDegree);
				Segment tmpSegment = new Segment(this.radius, startDegree, endDegree, parent, folders.get(i).getDirectoryName(), Color.orange, this.segments, this.mode);
				segments.add(tmpSegment);
				calculateRings(tmpSegment, folders.get(i), layer );
				startDegree = endDegree;
			}
			System.out.println("-------------------------------------");
		} else {
			Segment tmpSegment = new Segment(this.radius, 0.0, 360.0, null, tmpFileStructure.getDirectoryName(), Color.white, this.segments, this.mode);
			segments.add(tmpSegment);
			System.out.println("ROOT: " + tmpFileStructure.getFileStructure().size());
			calculateRings(tmpSegment, tmpFileStructure, layer);
		}
	}
	
	public void draw(PLayer layer) {
		//System.out.println("ANZAHL DER SEGMENTE: " + segments.size());
		PNode outputNode = PPath.createRectangle(150, 3, 900, 20);
		outputNode.setPaint(Color.GRAY);
		outputNode.removeAllChildren();
		layer.addChild(outputNode);
		for (int i = 0; i < segments.size(); i++) {
			//System.out.println("SEGMENT " + i + " " + segments.get(i).getStartDegree() + " " + segments.get(i).getEndDegree());
			segments.get(i).resetColor();
			
			segments.get(i).setOutputNode(outputNode);
			segments.get(i).setDiagramNode(this.diagramNode);
			this.diagramNode.addChild(segments.get(i));
			//layer.addChild(segments.get(i));
		}
		layer.addChild(this.diagramNode);
		//layer.addChild(segments.get(i));
	}
	
	public ArrayList<Segment> getSegments() {
		return this.segments;
	}
	
	public PNode getDiagramNode() {
		return this.diagramNode;
	}
	
	public int getDiagramMode() {
		return this.mode;
	}
	

}