import java.io.*;
import java.util.*;



public class FileStructure {
	
	private String directoryName;
	private File directory = null;
	private long directorySize;
	private double directoryPercentage;
	private ArrayList<FileObject> files = new ArrayList<FileObject>();
	private ArrayList<FileStructure> folders = new ArrayList<FileStructure>();

	
	public FileStructure(String directoryName) {	
		this.directoryName = directoryName;
		this.directory = new File(directoryName);
		readStructure();
		this.directorySize = calculateDirectorySize();
		this.directoryPercentage = 100.0;
		calculatePercentage(100.0);
	}
	
	public FileStructure(File tmpfile) {
		this.directoryName = tmpfile.getName();
		this.directory = tmpfile;
		readStructure();
		this.directorySize = calculateDirectorySize();
	}
	
	private void readStructure() {
		File[] tmpfiles = directory.listFiles();
		for (int i = 0; i < tmpfiles.length; i++) {
			File tmpfile = tmpfiles[i];
			if(tmpfile.isDirectory()) {
				//System.out.println("FILESTRUCTURE " + tmpfile.getName());
				FileStructure tmpStructure = new FileStructure(tmpfile);
				folders.add(tmpStructure);
			} else {
				//System.out.println("FILEOBJECT " + tmpfile.getName());
				FileObject tmpObject = new FileObject(tmpfile);
				files.add(tmpObject);
			}
		}
	}
	
	public String getDirectoryName() {
		return this.directoryName;
	}
	
	public ArrayList<FileStructure> getFileStructure() {
		return this.folders;
	}
	
	public ArrayList<FileObject> getFileObjects(){
		return this.files;
	}
	
	public void setDirectoryPercentage(double percentage) {
		this.directoryPercentage = percentage;
	}
	
	public double getDirectoryPercentage() {
		return this.directoryPercentage;
	}
	
	private long calculateDirectorySize() {
		long sum = 0;
		for (int i = 0; i < this.files.size(); i++) {
			sum = sum + this.files.get(i).getFileSize();
		}
		for (int i = 0; i < this.folders.size(); i++) {
			sum = sum + this.folders.get(i).calculateDirectorySize(); 
		}
		return sum;
	}
	
	private void calculatePercentage(double dir_percentage) {
		for (int i = 0; i < this.files.size(); i++) {
			double percentage = this.files.get(i).getFileSize() * this.directoryPercentage / this.directorySize;
			this.files.get(i).setFilePercentage(percentage);
			//System.out.println("CALCULATE PERCENTAGE: " + this.files.get(i).getFileName() + " " + percentage);
		}
		for (int i = 0; i < this.folders.size(); i++) {
			double percentage = this.folders.get(i).getDirectorySize() * this.directoryPercentage / this.directorySize;
			this.folders.get(i).setDirectoryPercentage(percentage);
			this.folders.get(i).calculatePercentage(percentage);
			//System.out.println("CALCULATE PERCENTAGE: " + this.folders.get(i).getDirectoryName() + " " + percentage);
		}
	}
	
	public long getDirectorySize() {
		return this.directorySize;
	}
}
