import java.awt.*;
import java.awt.event.KeyEvent;
import java.awt.geom.*;
import java.io.File;
import java.util.ArrayList;

import edu.umd.cs.piccolo.PLayer;
import edu.umd.cs.piccolo.PNode;
import edu.umd.cs.piccolo.event.PBasicInputEventHandler;
import edu.umd.cs.piccolo.event.PInputEvent;
import edu.umd.cs.piccolo.nodes.PPath;
import edu.umd.cs.piccolo.nodes.PText;
import edu.umd.cs.piccolo.util.PDimension;

public class Segment extends PPath {

	private int centerX = 500;
	private int centerY = 500;
	private int x; 
	private int y;
	private Segment parent = null;
	private Area fullArc =null;
	private Area Arc = null;
	private Area circle = null;
	private PPath ppathArc = null;
	private int radius;
	private double startDegree;
	private double endDegree;
	private String nodeName;
	private Color color;
	private ArrayList<Segment> segments;
//	private PLayer layer = null;
	private int mode;
	private PNode diagramNode;
	private PNode lastNode;
	private PNode outputNode;
	
	public void setDiagramNode(PNode diagramNode) {
		this.diagramNode = diagramNode;
	}
	
	public void setCenter(int x, int y) {
		this.centerX = x;
		this.centerY = y;
	}
	
	public int getCenterX(int x) {
		return this.centerX;
	}
	
	public int getCenterY(int y) {
		return this.centerY;
	}
	
	public int getRadius() {
		return this.radius;
	}
	
	public Area getArc() {
		return this.Arc;
	}
	
	public Area getFullArc() {
		return this.fullArc;
	}
	//Return this segment as circle
	public Area getCircle() {
		return this.circle;
	}
	
	public PPath getPPath() {
		return this.ppathArc;
	}
	
	public double getStartDegree() {
		return this.startDegree;
	}
	
	public String getNodeName() {
		return this.nodeName;
	}
	
	public double getEndDegree() {
		return this.endDegree;
	}
	
	public Color getColor() {
		return this.color;
	}
	
	public void setLastNode(PNode tmpNode) {
		this.lastNode = tmpNode;
	}
	
	public PNode getLastNode() {
		return this.lastNode;
	}
	
	public void resetColor() {
		this.setPaint(this.color);
	}
	
	public void setOutputNode(PNode outputNode) {
		this.outputNode = outputNode;
	}
	//	public Segment(int radius, double startDegree, double endDegree, Segment parent, String segmentName , Color color, ArrayList<Segment> segments, PLayer layer, int mode) {
	public Segment(int radius, double startDegree, double endDegree, Segment parent, String segmentName , Color color, ArrayList<Segment> segments, int mode) {
		this.parent = parent;
		this.startDegree = startDegree;
		this.endDegree = endDegree;
		this.nodeName = segmentName;
		this.color = color;
		this.segments = segments;
		//this.layer = layer;
		this.mode = mode;
		
		if (parent != null) {
			createSegment(radius, startDegree, endDegree);
			subtractSegment(parent);
			createNode();
		} else {
			createSegment(radius, startDegree, endDegree);
			createNode();
		}
	}
	
	private void createSegment(int radius, double startDegree, double endDegree) {
		if (parent != null) {
			this.radius = parent.getRadius()+radius;
			//System.out.println(this.radius);
			//System.out.println("Parent Radius:" + parent.getRadius());
			System.out.println("Degree: " + "S: " + startDegree + " E: " + endDegree);
			this.x = this.centerX - parent.getRadius()/2 - radius/2;
			this.y = this.centerY - parent.getRadius()/2 - radius/2;
			//System.out.println(this.x);
			//System.out.println(this.y);
		} else {
			this.radius = radius;
			//System.out.println(this.radius);
			//System.out.println("Degree: " + "S: " + startDegree + " E: " + endDegree);
			this.x = this.centerX - radius/2;
			this.y = this.centerY - radius/2;
			//System.out.println(this.x);
			//System.out.println(this.y);
		}
		//System.out.println("Radius of ARC: " + this.radius);
		double extendDegree = endDegree - startDegree;
		Arc2D arc = new Arc2D.Double(this.x, this.y, this.radius, this.radius, startDegree, extendDegree, Arc2D.PIE);
		this.Arc = new Area(arc);
		this.fullArc = new Area(arc);
		//extendDegree, um die Zirkellinie zu loeschen
		//Arc2D arc2 = new Arc2D.Double(this.x, this.y, this.radius, this.radius, startDegree, 360.0, Arc2D.PIE);
		//this.circle = new Area(arc2);
	}
	
	private void subtractSegment(Segment parent) {
		int parentRadius = parent.getRadius();
		Arc2D arc = new Arc2D.Double(parent.x, parent.y, parentRadius, parentRadius, this.startDegree-1, 360.0, Arc2D.PIE);
		Area tmp = new Area(arc);
		this.Arc.subtract(tmp);
	}
	
	public void setAction() {
		System.out.println("Name: " + getNodeName());
		System.out.println("Path: " + getFilePath());
		int x = this.centerX;
		int y = this.centerY;
		//OutputNode setzen
		this.outputNode.removeAllChildren();
		PText tmpText = new PText(this.getFilePath());
		tmpText.setX(this.outputNode.getX()+2);
		tmpText.setY(this.outputNode.getY()+2);
		this.outputNode.addChild(tmpText);
		for (int i = 0; i < this.segments.size(); i++) {
			//wegnehmen der gehighlightenden Nodes im Diagramm
			this.segments.get(i).removeAllChildren();
			//XY Koordinaten bestimmen fuer Kreise aussen
			if (x > this.segments.get(i).x) {
				x = this.segments.get(i).x;
			}
			if (y > this.segments.get(i).y) {
				y = this.segments.get(i).y;
			}
		}
		//hinzufuegen des gehighlightenden
		this.addChild(this.ppathArc);
		System.out.println("X: " + x);
		System.out.println("Y: " + y);
		System.out.println("Mode" + this.mode);
		File tmpFile = new File(getFilePath());
		if (tmpFile.isDirectory()) {
			if (this.mode == 1) {
				drawCircleView(x, y, getFilePath());
			}
			if (this.mode == 2) {
				drawSegmentView(x, y, getFilePath());
			}
			if (this.mode == 3) {
				drawInnerCircleView(getFilePath());
			}
		} else {
			if (this.lastNode != null) {
				this.diagramNode.removeChild(this.lastNode);
				for (int i = 0; i < this.segments.size(); i++) {
					this.segments.get(i).setLastNode(null);
				}
			}
		}
	}
	
	private String getFilePath() {
		String filePath = "";
		if (this.parent != null) {
			filePath = parent.getFilePath() + "\\" + this.nodeName;
		} else {
			filePath = this.nodeName;
		}
		return filePath;		
	}
	
	private void getFileName(PNode tmpNode) {
		PText tmpText = new PText(this.getFilePath());
		tmpText.setX(tmpNode.getX());
		tmpText.setY(tmpNode.getY());
		tmpNode.addChild(tmpText);
	}
	
	private void drawCircleView(int x, int y, String filePath) {
		FileStructure segmentDirectory = new FileStructure(filePath);
		System.out.println("DIRECTORYSIZE: " + segmentDirectory.getDirectorySize());
//		double directorySize = segmentDirectory.getDirectorySize();
//		double directoryPercentage = segmentDirectory.getDirectoryPercentage();
		ArrayList<FileObject> files = segmentDirectory.getFileObjects();
		ArrayList<FileStructure> folders = segmentDirectory.getFileStructure();
		int startDegree = 0;		
		PNode tmpNode = new PNode();
		if (this.lastNode != null) {
			this.diagramNode.removeChild(this.lastNode);
		}
		for (int i = 0; i < files.size(); i++) {
			System.out.println("FILE PERCENTAGE: " + files.get(i).getFilePercentage());
			int degree = (int) Math.ceil(files.get(i).getFilePercentage() * 360 / 100);
			System.out.println("DEGREE: " + degree);
			Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, startDegree-1, 360.0, Arc2D.PIE);
			Area area = new Area(arc);
			Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, startDegree, degree, Arc2D.PIE);
			Area area2 = new Area(arc2);
			area2.subtract(area);
			PPath tmp = new PPath(area2);
			tmp.setPaint(Color.green);
			tmp.addInputEventListener(new PBasicInputEventHandler() {
				Paint tmpPaint;
				public void mousePressed(PInputEvent event) {
					tmpPaint = event.getPickedNode().getPaint();
					event.getPickedNode().moveToFront();
					getFileName(event.getPickedNode());
					event.getPickedNode().setPaint(Color.RED);
					event.getInputManager().setKeyboardFocus(event.getPath());
					event.setHandled(true);
				}
				public void mouseDragged(PInputEvent event) {
					PNode aNode = event.getPickedNode();
					PDimension delta = event.getDeltaRelativeTo(aNode);
					aNode.translate(delta.width, delta.height);
					event.setHandled(true);
				}
				public void mouseReleased(PInputEvent event) {
					event.getPickedNode().removeAllChildren();
					event.getPickedNode().setPaint(tmpPaint);
					event.setHandled(true);
				}
			});
			tmpNode.addChild(tmp);
			//this.diagramNode.addChild(tmp);
			//this.layer.addChild(tmp);
			startDegree = startDegree + degree;
		}
		for (int i = 0; i < folders.size(); i++) {
			System.out.println("DIRECTORY PERCENTAGE: " + folders.get(i).getDirectoryPercentage());
			int degree = (int) Math.ceil(folders.get(i).getDirectoryPercentage() * 360 / 100);
			System.out.println("DEGREE: " + degree);
			Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, startDegree-1, 360.0, Arc2D.PIE);
			Area area = new Area(arc);
			Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, startDegree, degree, Arc2D.PIE);
			Area area2 = new Area(arc2);
			area2.subtract(area);
			PPath tmp = new PPath(area2);
			tmp.setPaint(Color.orange);
			tmp.addInputEventListener(new PBasicInputEventHandler() {
				Paint tmpPaint;
				public void mousePressed(PInputEvent event) {
					tmpPaint = event.getPickedNode().getPaint();
					event.getPickedNode().moveToFront();
					getFileName(event.getPickedNode());
					event.getPickedNode().setPaint(Color.RED);
					event.getInputManager().setKeyboardFocus(event.getPath());
					event.setHandled(true);
				}
				public void mouseDragged(PInputEvent event) {
					PNode aNode = event.getPickedNode();
					PDimension delta = event.getDeltaRelativeTo(aNode);
					aNode.translate(delta.width, delta.height);
					event.setHandled(true);
				}
				public void mouseReleased(PInputEvent event) {
					event.getPickedNode().removeAllChildren();
					event.getPickedNode().setPaint(tmpPaint);
					event.setHandled(true);
				}
			});
			tmpNode.addChild(tmp);
			//this.diagramNode.addChild(tmp);
			//this.layer.addChild(tmp);
			startDegree = startDegree + degree;
		}
		tmpNode.scaleAboutPoint(0.01, centerX, centerY);
		this.diagramNode.addChild(tmpNode);
		tmpNode.animateToPositionScaleRotation(0, 0, 1.0, 0.0, 5000);
		for (int i = 0; i < segments.size(); i++) {
			this.segments.get(i).setLastNode(tmpNode);
		}
//		Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, 180, 90, Arc2D.PIE);
//		Area area = new Area(arc);
//		Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, 180, 90, Arc2D.PIE);
//		Area area2 = new Area(arc2);
//		area2.subtract(area);
//		PPath circle = new PPath(area2);
//		circle.setPaint(Color.white);
//		this.layer.addChild(circle);
	}
	
	private void drawSegmentView(int x, int y, String filePath) {
		FileStructure segmentDirectory = new FileStructure(filePath);
		System.out.println("DIRECTORYSIZE: " + segmentDirectory.getDirectorySize());
//		double directorySize = segmentDirectory.getDirectorySize();
//		double directoryPercentage = segmentDirectory.getDirectoryPercentage();
		ArrayList<FileObject> files = segmentDirectory.getFileObjects();
		ArrayList<FileStructure> folders = segmentDirectory.getFileStructure();
		int startDegree = 180;
		int endDegree = 270;
		PNode tmpNode = new PNode();
		if (this.lastNode != null) {
			this.diagramNode.removeChild(this.lastNode);
		}
		for (int i = 0; i < files.size(); i++) {
			System.out.println("FILE PERCENTAGE: " + files.get(i).getFilePercentage());
			int degree = (int) Math.ceil(files.get(i).getFilePercentage() * 90 / 100);
//			if (startDegree + degree > endDegree) {
//				degree = endDegree - startDegree;
//			} else if (startDegree + degree < endDegree && i == files.size()-1 && folders == null) {
//				degree = endDegree - startDegree;
//			}
			System.out.println("DEGREE: " + degree);
			Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, startDegree-1, 360.0, Arc2D.PIE);
			Area area = new Area(arc);
			Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, startDegree, degree, Arc2D.PIE);
			Area area2 = new Area(arc2);
			area2.subtract(area);
			PPath tmp = new PPath(area2);
			tmp.setPaint(Color.green);
			tmp.addInputEventListener(new PBasicInputEventHandler() {
				Paint tmpPaint;
				public void mousePressed(PInputEvent event) {
					tmpPaint = event.getPickedNode().getPaint();
					event.getPickedNode().moveToFront();
					getFileName(event.getPickedNode());
					event.getPickedNode().setPaint(Color.RED);
					event.getInputManager().setKeyboardFocus(event.getPath());
					event.setHandled(true);
				}
				public void mouseDragged(PInputEvent event) {
					PNode aNode = event.getPickedNode();
					PDimension delta = event.getDeltaRelativeTo(aNode);
					aNode.translate(delta.width, delta.height);
					event.setHandled(true);
				}
				public void mouseReleased(PInputEvent event) {
					event.getPickedNode().removeAllChildren();
					event.getPickedNode().setPaint(tmpPaint);
					event.setHandled(true);
				}
			});
			//this.layer.addChild(tmp);
			//this.diagramNode.addChild(tmp);
			tmpNode.addChild(tmp);
			startDegree = startDegree + degree;
		}
		for (int i = 0; i < folders.size(); i++) {
			System.out.println("DIRECTORY PERCENTAGE: " + folders.get(i).getDirectoryPercentage());
			int degree = (int) Math.ceil(folders.get(i).getDirectoryPercentage() * 90 / 100);
//			if (startDegree + degree > endDegree) {
//				degree = endDegree - startDegree;
//			} else if (startDegree + degree < endDegree && i == folders.size()-1) {
//				degree = endDegree - startDegree;
//			}
			System.out.println("DEGREE: " + degree);
			//Der abzuziehende Kreis - 1 Grad um Strich zu entfernen
			Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, startDegree-1, 360.0, Arc2D.PIE);
			Area area = new Area(arc);
			Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, startDegree, degree, Arc2D.PIE);
			Area area2 = new Area(arc2);
			area2.subtract(area);
			PPath tmp = new PPath(area2);
			tmp.setPaint(Color.orange);
			tmp.addInputEventListener(new PBasicInputEventHandler() {
				Paint tmpPaint;
				public void mousePressed(PInputEvent event) {
					tmpPaint = event.getPickedNode().getPaint();
					event.getPickedNode().moveToFront();
					getFileName(event.getPickedNode());
					event.getPickedNode().setPaint(Color.RED);
					event.getInputManager().setKeyboardFocus(event.getPath());
					event.setHandled(true);
				}
				public void mouseDragged(PInputEvent event) {
					PNode aNode = event.getPickedNode();
					PDimension delta = event.getDeltaRelativeTo(aNode);
					aNode.translate(delta.width, delta.height);
					event.setHandled(true);
				}
				public void mouseReleased(PInputEvent event) {
					event.getPickedNode().removeAllChildren();
					event.getPickedNode().setPaint(tmpPaint);
					event.setHandled(true);
				}
			});
			//this.layer.addChild(tmp);
			//this.diagramNode.addChild(tmp);
			tmpNode.addChild(tmp);
			startDegree = startDegree + degree;
		}
		tmpNode.scaleAboutPoint(0.01, centerX, centerY);
		this.diagramNode.addChild(tmpNode);
		tmpNode.animateToPositionScaleRotation(0, 0, 1.0, 0.0, 5000);
		for (int i = 0; i < segments.size(); i++) {
			this.segments.get(i).setLastNode(tmpNode);
		}
//		Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, 180, 90, Arc2D.PIE);
//		Area area = new Area(arc);
//		Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, 180, 90, Arc2D.PIE);
//		Area area2 = new Area(arc2);
//		area2.subtract(area);
//		PPath circle = new PPath(area2);
//		circle.setPaint(Color.white);
//		this.layer.addChild(circle);
	}
	
	private void drawInnerCircleView(String filePath) {
		FileStructure segmentDirectory = new FileStructure(filePath);
		System.out.println("DIRECTORYSIZE: " + segmentDirectory.getDirectorySize());
//		double directorySize = segmentDirectory.getDirectorySize();
//		double directoryPercentage = segmentDirectory.getDirectoryPercentage();
		ArrayList<FileObject> files = segmentDirectory.getFileObjects();
		ArrayList<FileStructure> folders = segmentDirectory.getFileStructure();
		double startDegree = 0.0;
//		double endDegree = 360.0;
		PNode tmpNode = new PNode();
		if (this.lastNode != null) {
			this.diagramNode.removeChild(this.lastNode);
		}
		for (int i = 0; i < files.size(); i++) {
			System.out.println("FILE PERCENTAGE: " + files.get(i).getFilePercentage());
			double degree = files.get(i).getFilePercentage() * 360.0 / 100.0;
//			if (startDegree + degree > endDegree) {
//				degree = endDegree - startDegree;
//			} else if (startDegree + degree < endDegree && i == files.size()-1 && folders == null) {
//				degree = endDegree - startDegree;
//			}
			System.out.println("DEGREE: " + degree);
			Arc2D arc = new Arc2D.Double( this.centerX - 50, this.centerY - 50, 50 * 2, 50 * 2, startDegree-1, 360.0, Arc2D.PIE);
			Area area = new Area(arc);
			Arc2D arc2 = new Arc2D.Double(this.centerX - 100, this.centerY - 100, 100 * 2, 100 * 2, startDegree, degree, Arc2D.PIE);
			Area area2 = new Area(arc2);
			area2.subtract(area);
			PPath tmp = new PPath(area2);
			tmp.setPaint(Color.green);
			tmp.addInputEventListener(new PBasicInputEventHandler() {
				Paint tmpPaint;
				public void mousePressed(PInputEvent event) {
					tmpPaint = event.getPickedNode().getPaint();
					event.getPickedNode().moveToFront();
					getFileName(event.getPickedNode());
					event.getPickedNode().setPaint(Color.RED);
					event.getInputManager().setKeyboardFocus(event.getPath());
					event.setHandled(true);
				}
				public void mouseDragged(PInputEvent event) {
					PNode aNode = event.getPickedNode();
					PDimension delta = event.getDeltaRelativeTo(aNode);
					aNode.translate(delta.width, delta.height);
					event.setHandled(true);
				}
				public void mouseReleased(PInputEvent event) {
					event.getPickedNode().removeAllChildren();
					event.getPickedNode().setPaint(tmpPaint);
					event.setHandled(true);
				}
			});
			tmpNode.addChild(tmp);
			//this.layer.addChild(tmp);
			//this.diagramNode.addChild(tmp);
			startDegree = startDegree + degree;
		}
		for (int i = 0; i < folders.size(); i++) {
			System.out.println("DIRECTORY PERCENTAGE: " + folders.get(i).getDirectoryPercentage());
			double degree = folders.get(i).getDirectoryPercentage() * 360.0 / 100.0;
//			if (startDegree + degree > endDegree) {
//				degree = endDegree - startDegree;
//			} else if (startDegree + degree < endDegree && i == folders.size()-1) {
//				degree = endDegree - startDegree;
//			}
			System.out.println("DEGREE: " + degree);
			//Der abzuziehende Kreis - 1 Grad um Strich zu entfernen
//			Arc2D arc = new Arc2D.Double( x - 100, y - 100, (this.centerX - (x-100)) * 2, (this.centerY - (y-100)) * 2, startDegree-1, degree, Arc2D.PIE);
//			Area area = new Area(arc);
//			Arc2D arc2 = new Arc2D.Double( x - 125, y - 125, (this.centerX - (x-125)) * 2, (this.centerY - (y-125)) * 2, startDegree, degree, Arc2D.PIE);
//			Area area2 = new Area(arc2);
//			area2.subtract(area);

			Arc2D arc = new Arc2D.Double( this.centerX - 50, this.centerY - 50, 50 * 2, 50 * 2, startDegree-1, 360.0, Arc2D.PIE);
			Area area = new Area(arc);
			Arc2D arc2 = new Arc2D.Double(this.centerX - 100, this.centerY - 100, 100 * 2, 100 * 2, startDegree, degree, Arc2D.PIE);
			Area area2 = new Area(arc2);
			area2.subtract(area);
			PPath tmp = new PPath(area2);
			tmp.setPaint(Color.orange);
			tmp.addInputEventListener(new PBasicInputEventHandler() {
				Paint tmpPaint;
				public void mousePressed(PInputEvent event) {
					tmpPaint = event.getPickedNode().getPaint();
					event.getPickedNode().moveToFront();
					getFileName(event.getPickedNode());
					event.getPickedNode().setPaint(Color.RED);
					event.getInputManager().setKeyboardFocus(event.getPath());
					event.setHandled(true);
				}
				public void mouseDragged(PInputEvent event) {
					PNode aNode = event.getPickedNode();
					PDimension delta = event.getDeltaRelativeTo(aNode);
					aNode.translate(delta.width, delta.height);
					event.setHandled(true);
				}
				public void mouseReleased(PInputEvent event) {
					event.getPickedNode().removeAllChildren();
					event.getPickedNode().setPaint(tmpPaint);
					event.setHandled(true);
				}
			});
			tmpNode.addChild(tmp);
			//this.layer.addChild(tmp);
			//this.diagramNode.addChild(tmp);
			startDegree = startDegree + degree;
		}
		tmpNode.scaleAboutPoint(0.01, centerX, centerY);
		this.diagramNode.addChild(tmpNode);
		tmpNode.animateToPositionScaleRotation(0, 0, 1.0, 0.0, 5000);
		for (int i = 0; i < segments.size(); i++) {
			this.segments.get(i).setLastNode(tmpNode);
		}
//		Arc2D arc = new Arc2D.Double( x - 50, y - 50, (this.centerX - (x-50)) * 2, (this.centerY - (y-50)) * 2, 180, 90, Arc2D.PIE);
//		Area area = new Area(arc);
//		Arc2D arc2 = new Arc2D.Double( x - 75, y - 75, (this.centerX - (x-75)) * 2, (this.centerY - (y-75)) * 2, 180, 90, Arc2D.PIE);
//		Area area2 = new Area(arc2);
//		area2.subtract(area);
//		PPath circle = new PPath(area2);
//		circle.setPaint(Color.white);
//		this.layer.addChild(circle);
	}
	
	
	private void createNode() {
		this.append(this.Arc, true);
		//wird gebraucht fuer highlighting
		this.ppathArc = new PPath(this.Arc);
		this.ppathArc.setPaint(Color.RED);
		this.setPaint(this.color);
		this.addInputEventListener(new PBasicInputEventHandler() {
			public void mousePressed(PInputEvent event) {
				//event.getPickedNode().setPaint(Color.RED);
				setAction();
				event.getInputManager().setKeyboardFocus(event.getPath());
				event.setHandled(true);
			}
			public void mouseDragged(PInputEvent event) {
				PNode aNode = event.getPickedNode();
				PDimension delta = event.getDeltaRelativeTo(aNode);
				aNode.translate(delta.width, delta.height);
				event.setHandled(true);
			}
			public void mouseReleased(PInputEvent event) {
				//Color color = getColor();
				//event.getPickedNode().setPaint(Color.RED);
				event.setHandled(true);
			}
			public void keyPressed(PInputEvent event) {
				PNode node = event.getPickedNode();
				switch (event.getKeyCode()) {
					case KeyEvent.VK_UP:
						node.translate(0, -10f);
						break;
					case KeyEvent.VK_DOWN:
						node.translate(0, 10f);
						break;
					case KeyEvent.VK_LEFT:
						node.translate(-10f, 0);
						break;
					case KeyEvent.VK_RIGHT:
						node.translate(10f, 0);
						break;
				}
			}
		});
	}
	
	
	
}